@@ -1,5 +1,5 @@
 package Beam::Minion::Util;
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 # ABSTRACT: Utility functions for Beam::Minion
 
 #pod =head1 SYNOPSIS
@@ -28,6 +28,7 @@ use Scalar::Util qw( weaken );
 use Mojolicious;
 use Mojo::Log;
 use Beam::Wire;
+use YAML::PP qw( LoadFile );
 
 
 our @EXPORT_OK = qw( minion_init_args minion build_mojo_app );
@@ -39,6 +40,9 @@ our %BACKEND = (
     mysql => 'mysql',
 );
 
+# The saved init args, in case we override them with Beam::Minion->init
+our @INIT_ARGS = ();
+
 #pod =sub minion_init_args
 #pod
 #pod     my %args = minion_init_args();
@@ -50,6 +54,11 @@ our %BACKEND = (
 #pod
 #pod =over
 #pod
+#pod =item file://<path>
+#pod
+#pod A path to a YAML file of configuration to read. Should contain a single key and value
+#pod which are the Minion backend to use and the argument to its constructor.
+#pod
 #pod =item <url>
 #pod
 #pod A simple backend URL like C<postgres://postgres@/test>,
@@ -74,16 +83,30 @@ our %BACKEND = (
 #pod =cut
 
 sub minion_init_args {
+    if (@_) {
+      @INIT_ARGS = @_;
+    }
+    if (@INIT_ARGS) {
+        return @INIT_ARGS;
+    }
     die "You must set the BEAM_MINION environment variable to the Minion database URL.\n"
         . "See `perldoc Beam::Minion` for getting started instructions.\n"
         unless $ENV{BEAM_MINION};
     my ( $backend, $url );
+    # If there's a `+`, we must be doing multi-args
     if ( $ENV{BEAM_MINION} =~ /^[^+:]+\+/ ) {
-        my @args = split /\+/, $ENV{BEAM_MINION};
-        return @args;
+        @INIT_ARGS = split /\+/, $ENV{BEAM_MINION};
+        return @INIT_ARGS;
     }
     my ( $schema ) = $ENV{BEAM_MINION} =~ /^([^:]+)/;
-    return $BACKEND{ $schema }, $ENV{BEAM_MINION};
+    # Load config from a YAML file
+    if ($schema eq 'file') {
+      my ( undef, $path ) = split '://', $ENV{BEAM_MINION};
+      @INIT_ARGS = (LoadFile($path))[0]->%*;
+      return @INIT_ARGS;
+    }
+    @INIT_ARGS = ($BACKEND{ $schema }, $ENV{BEAM_MINION});
+    return @INIT_ARGS;
 }
 
 #pod =sub minion
@@ -160,7 +183,7 @@ Beam::Minion::Util - Utility functions for Beam::Minion
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
@@ -186,6 +209,11 @@ This environment variable can take a few forms:
 
 =over
 
+=item file://<path>
+
+A path to a YAML file of configuration to read. Should contain a single key and value
+which are the Minion backend to use and the argument to its constructor.
+
 =item <url>
 
 A simple backend URL like C<postgres://postgres@/test>,
